@@ -2,20 +2,23 @@
 #
 # Author: Dan Garrette <dhgarrette@gmail.com>
 #
-# Copyright (C) 2001-2012 NLTK Project
-# URL: <http://www.nltk.org/>
+# Copyright (C) 2001-2015 NLTK Project
+# URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
+from __future__ import print_function, division, unicode_literals
 
 import os
 
 import nltk
 from nltk.internals import Counter
+from nltk.compat import string_types
 from nltk.corpus import brown
 from nltk.tag import UnigramTagger, BigramTagger, TrigramTagger, RegexpTagger
-from nltk.sem.logic import (LogicParser, Expression, Variable, VariableExpression,
+from nltk.sem.logic import (Expression, Variable, VariableExpression,
                             LambdaExpression, AbstractVariableExpression)
-import drt
-import linearlogic
+from nltk.compat import python_2_unicode_compatible
+from nltk.sem import drt
+from nltk.sem import linearlogic
 
 SPEC_SEMTYPES = {'a'       : 'ex_quant',
                  'an'      : 'ex_quant',
@@ -26,24 +29,25 @@ SPEC_SEMTYPES = {'a'       : 'ex_quant',
 
 OPTIONAL_RELATIONSHIPS = ['nmod', 'vmod', 'punct']
 
+@python_2_unicode_compatible
 class GlueFormula(object):
     def __init__(self, meaning, glue, indices=None):
         if not indices:
             indices = set()
 
-        if isinstance(meaning, str):
-            self.meaning = LogicParser().parse(meaning)
+        if isinstance(meaning, string_types):
+            self.meaning = Expression.fromstring(meaning)
         elif isinstance(meaning, Expression):
             self.meaning = meaning
         else:
-            raise RuntimeError, 'Meaning term neither string or expression: %s, %s' % (meaning, meaning.__class__)
+            raise RuntimeError('Meaning term neither string or expression: %s, %s' % (meaning, meaning.__class__))
 
-        if isinstance(glue, str):
+        if isinstance(glue, string_types):
             self.glue = linearlogic.LinearLogicParser().parse(glue)
         elif isinstance(glue, linearlogic.Expression):
             self.glue = glue
         else:
-            raise RuntimeError, 'Glue term neither string or expression: %s, %s' % (glue, glue.__class__)
+            raise RuntimeError('Glue term neither string or expression: %s, %s' % (glue, glue.__class__))
 
         self.indices = indices
 
@@ -53,14 +57,14 @@ class GlueFormula(object):
             returns ((walk john),          f)
         """
         if self.indices & arg.indices: # if the sets are NOT disjoint
-            raise linearlogic.LinearLogicApplicationException, "'%s' applied to '%s'.  Indices are not disjoint." % (self, arg)
+            raise linearlogic.LinearLogicApplicationException("'%s' applied to '%s'.  Indices are not disjoint." % (self, arg))
         else: # if the sets ARE disjoint
             return_indices = (self.indices | arg.indices)
 
         try:
             return_glue = linearlogic.ApplicationExpression(self.glue, arg.glue, arg.indices)
         except linearlogic.LinearLogicApplicationException:
-            raise linearlogic.LinearLogicApplicationException, "'%s' applied to '%s'" % (self.simplify(), arg.simplify())
+            raise linearlogic.LinearLogicApplicationException("'%s' applied to '%s'" % (self.simplify(), arg.simplify()))
 
         arg_meaning_abstracted = arg.meaning
         if return_indices:
@@ -97,19 +101,24 @@ class GlueFormula(object):
     def __eq__(self, other):
         return self.__class__ == other.__class__ and self.meaning == other.meaning and self.glue == other.glue
 
+    def __ne__(self, other):
+        return not self == other
+
     def __str__(self):
         assert isinstance(self.indices, set)
         accum = '%s : %s' % (self.meaning, self.glue)
         if self.indices:
-            accum += ' : {' + ', '.join([str(index) for index in self.indices]) + '}'
+            accum += ' : {' + ', '.join(str(index) for index in self.indices) + '}'
         return accum
 
     def __repr__(self):
-        return str(self)
+        return "%s" % self
 
+@python_2_unicode_compatible
 class GlueDict(dict):
-    def __init__(self, filename):
+    def __init__(self, filename, encoding=None):
         self.filename = filename
+        self.file_encoding = encoding
         self.read_file()
 
     def read_file(self, empty_first=True):
@@ -117,19 +126,14 @@ class GlueDict(dict):
             self.clear()
 
         try:
-            f = nltk.data.find(
-                os.path.join('grammars', 'sample_grammars', self.filename))
-            # if f is a ZipFilePathPointer or a FileSystemPathPointer
-            # then we need a little extra massaging
-            if hasattr(f, 'open'):
-                f = f.open()
-        except LookupError, e:
+            contents = nltk.data.load(self.filename, format='text', encoding=self.file_encoding)
+            # TODO: the above can't handle zip files, but this should anyway be fixed in nltk.data.load()
+        except LookupError as e:
             try:
-                f = open(self.filename)
+                contents = nltk.data.load('file:' + self.filename, format='text', encoding=self.file_encoding)
             except LookupError:
                 raise e
-        lines = f.readlines()
-        f.close()
+        lines = contents.splitlines()
 
         for line in lines:                          # example: 'n : (\\x.(<word> x), (v-or))'
                                                     #     lambdacalc -^  linear logic -^
@@ -140,7 +144,7 @@ class GlueDict(dict):
             parts = line.split(' : ', 2)            # ['verb', '(\\x.(<word> x), ( subj -o f ))', '[subj]']
 
             glue_formulas = []
-            parenCount = 0
+            paren_count = 0
             tuple_start = 0
             tuple_comma = 0
 
@@ -149,36 +153,36 @@ class GlueDict(dict):
             if len(parts) > 1:
                 for (i, c) in enumerate(parts[1]):
                     if c == '(':
-                        if parenCount == 0:             # if it's the first '(' of a tuple
+                        if paren_count == 0:             # if it's the first '(' of a tuple
                             tuple_start = i+1           # then save the index
-                        parenCount += 1
+                        paren_count += 1
                     elif c == ')':
-                        parenCount -= 1
-                        if parenCount == 0:             # if it's the last ')' of a tuple
+                        paren_count -= 1
+                        if paren_count == 0:             # if it's the last ')' of a tuple
                             meaning_term =  parts[1][tuple_start:tuple_comma]   # '\\x.(<word> x)'
                             glue_term =     parts[1][tuple_comma+1:i]           # '(v-r)'
                             glue_formulas.append([meaning_term, glue_term])     # add the GlueFormula to the list
                     elif c == ',':
-                        if parenCount == 1:             # if it's a comma separating the parts of the tuple
+                        if paren_count == 1:             # if it's a comma separating the parts of the tuple
                             tuple_comma = i             # then save the index
                     elif c == '#':                      # skip comments at the ends of lines
-                        if parenCount != 0:             # if the line hasn't parsed correctly so far
-                            raise RuntimeError, 'Formula syntax is incorrect for entry ' + line
+                        if paren_count != 0:             # if the line hasn't parsed correctly so far
+                            raise RuntimeError('Formula syntax is incorrect for entry ' + line)
                         break                           # break to the next line
 
             if len(parts) > 2:                      #if there is a relationship entry at the end
-                relStart = parts[2].index('[')+1
-                relEnd   = parts[2].index(']')
-                if relStart == relEnd:
+                rel_start = parts[2].index('[')+1
+                rel_end   = parts[2].index(']')
+                if rel_start == rel_end:
                     relationships = frozenset()
                 else:
-                    relationships = frozenset([r.strip() for r in parts[2][relStart:relEnd].split(',')])
+                    relationships = frozenset(r.strip() for r in parts[2][rel_start:rel_end].split(','))
 
             try:
-                startInheritance = parts[0].index('(')
-                endInheritance = parts[0].index(')')
-                sem = parts[0][:startInheritance].strip()
-                supertype = parts[0][startInheritance+1:endInheritance]
+                start_inheritance = parts[0].index('(')
+                end_inheritance = parts[0].index(')')
+                sem = parts[0][:start_inheritance].strip()
+                supertype = parts[0][start_inheritance+1:end_inheritance]
             except:
                 sem = parts[0].strip()
                 supertype = None
@@ -189,9 +193,10 @@ class GlueDict(dict):
             if relationships is None: #if not specified for a specific relationship set
                 #add all relationship entries for parents
                 if supertype:
-                    for rels, glue in self[supertype].iteritems():
+                    for rels in self[supertype]:
                         if rels not in self[sem]:
                             self[sem][rels] = []
+                        glue = self[supertype][rels]
                         self[sem][rels].extend(glue)
                         self[sem][rels].extend(glue_formulas) # add the glue formulas to every rel entry
                 else:
@@ -205,33 +210,35 @@ class GlueDict(dict):
                     self[sem][relationships].extend(self[supertype][relationships])
                 self[sem][relationships].extend(glue_formulas) # add the glue entry to the dictionary
 
-
     def __str__(self):
         accum = ''
         for pos in self:
+            str_pos = "%s" % pos
             for relset in self[pos]:
                 i = 1
                 for gf in self[pos][relset]:
-                    if i==1:
-                        accum += str(pos) + ': '
+                    if i == 1:
+                        accum += str_pos + ': '
                     else:
-                        accum += ' '*(len(str(pos))+2)
-                    accum += str(gf)
-                    if relset and i==len(self[pos][relset]):
-                        accum += ' : ' + str(relset)
+                        accum += ' '*(len(str_pos)+2)
+                    accum += "%s" % gf
+                    if relset and i == len(self[pos][relset]):
+                        accum += ' : %s' % relset
                     accum += '\n'
                     i += 1
         return accum
 
     def to_glueformula_list(self, depgraph, node=None, counter=None, verbose=False):
         if node is None:
-            top = depgraph.nodelist[0]
-            root = depgraph.nodelist[top['deps'][0]]
+            top = depgraph.nodes[0]
+            depList = sum(list(top['deps'].values()), [])
+            root = depgraph.nodes[depList[0]]
+            #print (root) 
             return self.to_glueformula_list(depgraph, root, Counter(), verbose)
 
         glueformulas = self.lookup(node, depgraph, counter)
-        for dep_idx in node['deps']:
-            dep = depgraph.nodelist[dep_idx]
+        for dep_idx in sum(list(node['deps'].values()), []):
+            dep = depgraph.nodes[dep_idx]
             glueformulas.extend(self.to_glueformula_list(depgraph, dep, counter, verbose))
         return glueformulas
 
@@ -244,7 +251,7 @@ class GlueDict(dict):
                 semtype = self[name]
                 break
         if semtype is None:
-#            raise KeyError, "There is no GlueDict entry for sem type '%s' (for '%s')" % (sem, word)
+            # raise KeyError, "There is no GlueDict entry for sem type '%s' (for '%s')" % (sem, word)
             return []
 
         self.add_missing_dependencies(node, depgraph)
@@ -252,9 +259,11 @@ class GlueDict(dict):
         lookup = self._lookup_semtype_option(semtype, node, depgraph)
 
         if not len(lookup):
-            raise KeyError, "There is no GlueDict entry for sem type of '%s'"\
-                    " with tag '%s', and rel '%s'" %\
-                    (node['word'], node['tag'], node['rel'])
+            raise KeyError(
+                "There is no GlueDict entry for sem type of '%s' "
+                "with tag '%s', and rel '%s'" %
+                (node['word'], node['tag'], node['rel'])
+                )
 
         return self.get_glueformulas_from_semtype_entry(lookup, node['word'], node, depgraph, counter)
 
@@ -262,15 +271,19 @@ class GlueDict(dict):
         rel = node['rel'].lower()
 
         if rel == 'main':
-            headnode = depgraph.nodelist[node['head']]
+            headnode = depgraph.nodes[node['head']]
             subj = self.lookup_unique('subj', headnode, depgraph)
-            node['deps'].append(subj['address'])
+            relation = subj['rel']
+            node['deps'].setdefault(relation,[])
+            node['deps'][relation].append(subj['address'])
+            #node['deps'].append(subj['address'])
 
     def _lookup_semtype_option(self, semtype, node, depgraph):
-        relationships = frozenset([depgraph.nodelist[dep]['rel'].lower()
-                                   for dep in node['deps']
-                                   if depgraph.nodelist[dep]['rel'].lower()
-                                       not in OPTIONAL_RELATIONSHIPS])
+        relationships = frozenset(
+            depgraph.nodes[dep]['rel'].lower()
+            for dep in sum(list(node['deps'].values()), [])
+            if depgraph.nodes[dep]['rel'].lower() not in OPTIONAL_RELATIONSHIPS
+        )
 
         try:
             lookup = semtype[relationships]
@@ -298,8 +311,6 @@ class GlueDict(dict):
         Based on the node, return a list of plausible semtypes in order of
         plausibility.
         """
-        semtype_name = None
-
         rel = node['rel'].lower()
         word = node['word'].lower()
 
@@ -347,8 +358,9 @@ class GlueDict(dict):
                 return linearlogic.ConstantExpression(name)
         else:
             return linearlogic.ImpExpression(
-                       self.initialize_labels(expr.antecedent, node, depgraph, unique_index),
-                       self.initialize_labels(expr.consequent, node, depgraph, unique_index))
+                self.initialize_labels(expr.antecedent, node, depgraph, unique_index),
+                self.initialize_labels(expr.consequent, node, depgraph, unique_index)
+            )
 
     def find_label_name(self, name, node, depgraph, unique_index):
         try:
@@ -357,19 +369,27 @@ class GlueDict(dict):
             before_dot = name[:dot]
             after_dot = name[dot+1:]
             if before_dot == 'super':
-                return self.find_label_name(after_dot, depgraph.nodelist[node['head']], depgraph, unique_index)
+                return self.find_label_name(after_dot, depgraph.nodes[node['head']], depgraph, unique_index)
             else:
                 return self.find_label_name(after_dot, self.lookup_unique(before_dot, node, depgraph), depgraph, unique_index)
         except ValueError:
             lbl = self.get_label(node)
-            if   name=='f':     return lbl
-            elif name=='v':     return '%sv' % lbl
-            elif name=='r':     return '%sr' % lbl
-            elif name=='super': return self.get_label(depgraph.nodelist[node['head']])
-            elif name=='var':   return '%s%s' % (lbl.upper(), unique_index)
-            elif name=='a':     return self.get_label(self.lookup_unique('conja', node, depgraph))
-            elif name=='b':     return self.get_label(self.lookup_unique('conjb', node, depgraph))
-            else:               return self.get_label(self.lookup_unique(name, node, depgraph))
+            if name == 'f':
+                return lbl
+            elif name == 'v':
+                return '%sv' % lbl
+            elif name == 'r':
+                return '%sr' % lbl
+            elif name == 'super':
+                return self.get_label(depgraph.nodes[node['head']])
+            elif name == 'var':
+                return '%s%s' % (lbl.upper(), unique_index)
+            elif name == 'a':
+                return self.get_label(self.lookup_unique('conja', node, depgraph))
+            elif name == 'b':
+                return self.get_label(self.lookup_unique('conjb', node, depgraph))
+            else:
+                return self.get_label(self.lookup_unique(name, node, depgraph))
 
     def get_label(self, node):
         """
@@ -382,7 +402,7 @@ class GlueDict(dict):
 
         letter = ['f','g','h','i','j','k','l','m','n','o','p','q','r','s',
                   't','u','v','w','x','y','z','a','b','c','d','e'][value-1]
-        num = int(value) / 26
+        num = int(value) // 26
         if num > 0:
             return letter + str(num)
         else:
@@ -392,19 +412,23 @@ class GlueDict(dict):
         """
         Lookup 'key'. There should be exactly one item in the associated relation.
         """
-        deps = [depgraph.nodelist[dep] for dep in node['deps']
-                if depgraph.nodelist[dep]['rel'].lower() == rel.lower()]
+        deps = [
+            depgraph.nodes[dep]
+            for dep in sum(list(node['deps'].values()), [])
+            if depgraph.nodes[dep]['rel'].lower() == rel.lower()
+        ]
 
         if len(deps) == 0:
-            raise KeyError, "'%s' doesn't contain a feature '%s'" % (node['word'], rel)
+            raise KeyError("'%s' doesn't contain a feature '%s'" % (node['word'], rel))
         elif len(deps) > 1:
-            raise KeyError, "'%s' should only have one feature '%s'" % (node['word'], rel)
+            raise KeyError("'%s' should only have one feature '%s'" % (node['word'], rel))
         else:
             return deps[0]
 
     def get_GlueFormula_factory(self):
         return GlueFormula
 
+
 class Glue(object):
     def __init__(self, semtype_file=None, remove_duplicates=False,
                  depparser=None, verbose=False):
@@ -418,7 +442,7 @@ class Glue(object):
         if semtype_file:
             self.semtype_file = semtype_file
         else:
-            self.semtype_file = 'glue.semtype'
+            self.semtype_file = os.path.join('grammars', 'sample_grammars','glue.semtype')
 
     def train_depparser(self, depgraphs=None):
         if depgraphs:
@@ -501,28 +525,27 @@ class Glue(object):
                 try:
                     if reading.equiv(glueformula.meaning, self.prover):
                         add_reading = False
-                        break;
-                except Exception, e:
+                        break
+                except Exception as e:
                     #if there is an exception, the syntax of the formula
                     #may not be understandable by the prover, so don't
                     #throw out the reading.
-                    print 'Error when checking logical equality of statements', e
+                    print('Error when checking logical equality of statements', e)
                     pass
         if add_reading:
             reading_list.append(glueformula.meaning)
 
-    def parse_to_compiled(self, sentence='a man sees Mary'.split()):
+    def parse_to_compiled(self, sentence):
         gfls = [self.depgraph_to_glue(dg) for dg in self.dep_parse(sentence)]
         return [self.gfl_to_compiled(gfl) for gfl in gfls]
 
-    def dep_parse(self, sentence='every cat leaves'.split()):
+    def dep_parse(self, sentence):
         #Lazy-initialize the depparser
         if self.depparser is None:
             from nltk.parse import MaltParser
             self.depparser = MaltParser(tagger=self.get_pos_tagger())
         if not self.depparser._trained:
             self.train_depparser()
-
         return [self.depparser.parse(sentence, verbose=self.verbose)]
 
     def depgraph_to_glue(self, depgraph):
@@ -538,9 +561,9 @@ class Glue(object):
             return_list.extend(gf.compile(index_counter))
 
         if self.verbose:
-            print 'Compiled Glue Premises:'
+            print('Compiled Glue Premises:')
             for cgf in return_list:
-                print cgf
+                print(cgf)
 
         return return_list
 
@@ -575,19 +598,19 @@ class DrtGlueFormula(GlueFormula):
         if not indices:
             indices = set()
 
-        if isinstance(meaning, str):
-            self.meaning = drt.DrtParser().parse(meaning)
-        elif isinstance(meaning, drt.AbstractDrs):
+        if isinstance(meaning, string_types):
+            self.meaning = drt.DrtExpression.fromstring(meaning)
+        elif isinstance(meaning, drt.DrtExpression):
             self.meaning = meaning
         else:
-            raise RuntimeError, 'Meaning term neither string or expression: %s, %s' % (meaning, meaning.__class__)
+            raise RuntimeError('Meaning term neither string or expression: %s, %s' % (meaning, meaning.__class__))
 
-        if isinstance(glue, str):
+        if isinstance(glue, string_types):
             self.glue = linearlogic.LinearLogicParser().parse(glue)
         elif isinstance(glue, linearlogic.Expression):
             self.glue = glue
         else:
-            raise RuntimeError, 'Glue term neither string or expression: %s, %s' % (glue, glue.__class__)
+            raise RuntimeError('Glue term neither string or expression: %s, %s' % (glue, glue.__class__))
 
         self.indices = indices
 
@@ -605,7 +628,7 @@ class DrtGlue(Glue):
     def __init__(self, semtype_file=None, remove_duplicates=False,
                  depparser=None, verbose=False):
         if not semtype_file:
-            semtype_file = 'drt_glue.semtype'
+            semtype_file = os.path.join('grammars', 'sample_grammars','drt_glue.semtype')
         Glue.__init__(self, semtype_file, remove_duplicates, depparser, verbose)
 
     def get_glue_dict(self):
@@ -630,7 +653,7 @@ def demo(show_example=-1):
 #                'every big gray cat leaves',
 #                'a former senator leaves',
 
-    print '============== DEMO =============='
+    print('============== DEMO ==============')
 
     tagger = RegexpTagger(
         [('^(David|Mary|John)$', 'NNP'),
@@ -648,10 +671,10 @@ def demo(show_example=-1):
 
     for (i, sentence) in enumerate(examples):
         if i==show_example or show_example==-1:
-            print '[[[Example %s]]]  %s' % (i, sentence)
+            print('[[[Example %s]]]  %s' % (i, sentence))
             for reading in glue.parse_to_meaning(sentence.split()):
-                print reading.simplify()
-            print ''
+                print(reading.simplify())
+            print('')
 
 
 if __name__ == '__main__':
